@@ -1,5 +1,5 @@
 from dataclasses import dataclass, field
-from typing import List
+from typing import List, Union
 
 from dataclasses_json import dataclass_json
 
@@ -19,7 +19,7 @@ class JiraTestScriptStep:
 class JiraTestScript:
     id: str = ""
     text: str = ""
-    type: str = "PLAIN_TEXT" # PLAIN_TEXT | STEP_BY_STEP
+    type: str = "PLAIN_TEXT"  # PLAIN_TEXT | STEP_BY_STEP
     steps: List[JiraTestScriptStep] = field(default_factory=list)
 
 
@@ -27,10 +27,12 @@ class JiraTestScript:
 @dataclass
 class JiraTestcase:
     # owner: str = ""
+    id: int = 0
     key: str = ""
     projectKey: str = ""
     name: str = ""
-    status: str = "Draft" # Approved | Draft
+    folder: str = ""
+    status: str = "Draft"  # Approved | Draft
     # lastTestResultStatus: str = ""
     priority: str = "Normal"
     # createdOn: str = ""
@@ -39,9 +41,12 @@ class JiraTestcase:
     precondition: str = ""
     testScript: JiraTestScript = None
     issueLinks: List[str] = field(default_factory=list)
+    confluenceLinks: List[str] = field(default_factory=list)
+    webLinks: List[Union[str, dict]] = field(default_factory=list)
     # parameters: dict = None
 
     # test result fields
+    testrun_folder: str = ""
     testrun_status: str = ""
     testrun_environment: str = ""
     testrun_comment: str = ""
